==> lhcsmapi-1.1.185.tar.gz: lhcsmapi-1.1.185/lhcsmapi/analysis/qds/iqds/IqdsPlot.py <==
import matplotlib.pyplot as plt


class IqdsPlot(object):

    @staticmethod
    def plot_u_qds(u_qds_df, timestamp_qds, timestamp_pic, *, title, xmin, xmax, xlim, ax=None):
        if ax is not None:
            ax1 = u_qds_df['U_QS0'].plot(ax=ax, title='iQPS', color='C0', grid=True, xlim=xlim, legend=True)
        else:
            ax1 = u_qds_df['U_QS0'].plot(title=title, figsize=(15, 7.5), color='C0', grid=True, xlim=xlim, legend=True)

        ax1.title.set_size(20)
        ax1.axvline(x=timestamp_pic - timestamp_qds * 1e-9, color='green', linestyle='--', linewidth=1.5)
        ax1.legend(['U_QS0'], loc='lower left')
        ax1.set_ylabel("U_QS0, [V]", color='C0', fontsize=15)
        ax1.set_xlabel("time, [s]", fontsize=15)
        ax1.tick_params(labelsize=15)
        ax1.axhspan(ymin=-0.1, ymax=+0.1, facecolor='xkcd:yellowgreen')
        ax1.axvspan(xmin=xmin, xmax=xmax, facecolor='xkcd:goldenrod')

        ax2 = ax1.twinx()
        u_qds_df["U_1"].plot(ax=ax2, color='C1', xlim=xlim)
        u_qds_df["U_2"].plot(ax=ax2, color='C2', xlim=xlim)
        ax2.legend(['U_1', 'U_2'], loc='upper right')
        ax2.set_ylabel("U_1, U_2, [V]", color='C1', fontsize=15)
        ax2.set_xlabel("time, [s]", fontsize=15)
        ax2.tick_params(labelsize=15)

        if ax is None:
            plt.show()

    @staticmethod
    def plot_st_qds(u_qds_df, *, title, xmin, xmax, xlim, ax=None):
        if ax is not None:
            ax1 = u_qds_df["U_QS0"].plot(ax=ax, style='o-', grid=True, xlim=xlim, legend=True)
        else:
            ax1 = u_qds_df["U_QS0"].plot(title=title, figsize=(15, 7.5), style='o-', grid=True, xlim=xlim, legend=True)
        ax1.title.set_size(20)
        ax1.legend(['U_QS0'], loc='lower left')
        ax1.set_xlabel("time, [s]", fontsize=15)
        ax1.set_ylabel("U_QS0, [V]", color='C0', fontsize=15)
        ax1.tick_params(labelsize=15)
        ax1.axhspan(ymin=-0.1, ymax=+0.1, facecolor='xkcd:yellowgreen')  # beige
        ax1.axvspan(xmin=xmin, xmax=xmax, facecolor='xkcd:goldenrod')

        ax2 = ax1.twinx()
        u_qds_df["ST_MAGNET_OK"].astype(int).plot(ax=ax2, yticks=[0, 1], ylim=[-0.1, 1.1],
                                                  style={'ST_MAGNET_OK': 'ro-'}, xlim=xlim, grid=True)
        u_qds_df["ST_NQD0"].astype(int).plot(ax=ax2, yticks=[0, 1], ylim=[-0.1, 1.1], style={'ST_NQD0': 'bx-'},
                                             xlim=xlim, grid=True)

        ax2.set_ylabel("ST_NDQ0, ST_MAGNET_OK, [-]", color='C3', fontsize=15)
        ax2.legend(['ST_NDQ0', 'ST_MAGNET_OK'], loc='upper right')
        ax2.tick_params(labelsize=15)

        if ax is None:
            plt.show()

==> lhcsmapi-1.2.111.tar.gz: lhcsmapi-1.2.111/lhcsmapi/analysis/qds/iqds/IqdsPlot.py <==
import matplotlib.pyplot as plt


class IqdsPlot(object):

    @staticmethod
    def plot_u_qds(u_qds_df, timestamp_qds, timestamp_pic, *, title, xmin, xmax, xlim, ax=None):
        if ax is None:
            ax1 = u_qds_df['U_QS0'].plot(title=title, figsize=(15, 7.5), color='C0', grid=True, xlim=xlim, legend=True)
        else:
            ax1 = u_qds_df['U_QS0'].plot(ax=ax, title='iQPS', color='C0', grid=True, xlim=xlim, legend=True)

        ax1.title.set_size(20)
        ax1.axvline(x=timestamp_pic - timestamp_qds * 1e-9, color='green', linestyle='--', linewidth=1.5)
        ax1.legend(['U_QS0'], loc='lower left')
        ax1.set_ylabel("U_QS0, [V]", color='C0', fontsize=15)
        ax1.set_xlabel("time, [s]", fontsize=15)
        ax1.tick_params(labelsize=15)
        ax1.axhspan(ymin=-0.1, ymax=+0.1, facecolor='xkcd:yellowgreen')
        ax1.axvspan(xmin=xmin, xmax=xmax, facecolor='xkcd:goldenrod')

        ax2 = ax1.twinx()
        u_qds_df["U_1"].plot(ax=ax2, color='C1', xlim=xlim)
        u_qds_df["U_2"].plot(ax=ax2, color='C2', xlim=xlim)
        ax2.legend(['U_1', 'U_2'], loc='upper right')
        ax2.set_ylabel("U_1, U_2, [V]", fontsize=15)
        ax2.set_xlabel("time, [s]", fontsize=15)
        ax2.tick_params(labelsize=15)

        if ax is None:
            plt.show()

    @staticmethod
    def plot_st_qds(u_qds_df, *, title, xmin, xmax, xlim, ax=None):
        if ax is None:
            ax1 = u_qds_df["U_QS0"].plot(title=title, figsize=(15, 7.5), style='o-', grid=True, xlim=xlim, legend=True)
        else:
            ax1 = u_qds_df["U_QS0"].plot(ax=ax, style='o-', grid=True, xlim=xlim, legend=True)

        ax1.title.set_size(20)
        ax1.legend(['U_QS0'], loc='lower left')
        ax1.set_xlabel("time, [s]", fontsize=15)
        ax1.set_ylabel("U_QS0, [V]", color='C0', fontsize=15)
        ax1.tick_params(labelsize=15)
        ax1.axhspan(ymin=-0.1, ymax=+0.1, facecolor='xkcd:yellowgreen')  # beige
        ax1.axvspan(xmin=xmin, xmax=xmax, facecolor='xkcd:goldenrod')

        ax2 = ax1.twinx()
        u_qds_df["ST_MAGNET_OK"].astype(int).plot(ax=ax2, yticks=[0, 1], ylim=[-0.1, 1.1], drawstyle="steps-post",
                                                  style={'ST_MAGNET_OK': 'ro-'}, xlim=xlim, grid=True)
        u_qds_df["ST_NQD0"].astype(int).plot(ax=ax2, yticks=[0, 1], ylim=[-0.1, 1.1], style={'ST_NQD0': 'bx-'}, drawstyle="steps-post",
                                             xlim=xlim, grid=True)

        ax2.set_ylabel("ST_NDQ0, ST_MAGNET_OK, [-]", fontsize=15)
        ax2.legend(['ST_NDQ0', 'ST_MAGNET_OK'], loc='upper right')
        ax2.tick_params(labelsize=15)

        if ax is None:
            plt.show()
